Keyring

Enum Keyring 

pub enum Keyring {
    Locked(LockedKeyring),
    Unlocked(UnlockedKeyring),
}

Variants

Implementations

Source

impl Keyring

pub async fn validate_secret(&self, secret: &Secret) -> Result<bool, Error>

Validate that a secret can decrypt the items in this keyring.

pub async fn validate_unencrypted(&self) -> Result<bool, Error>

pub async fn modified_time(&self) -> Duration

Get the modification timestamp

pub async fn created_time(&self) -> Option<Duration>

Get the creation timestamp from the filesystem if the keyring has an associated file.

pub async fn items(&self) -> Result<Vec<Item>, Error>

pub fn path(&self) -> Option<&Path>

Return the associated file if any.

pub const fn is_locked(&self) -> bool

pub fn as_unlocked(&self) -> &UnlockedKeyring

pub fn as_locked(&self) -> &LockedKeyring